@@ -1,39 +1,36 @@
-/*
- *  This file is part of the KDE libraries
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- *
- */
+/*  SPDX-License-Identifier: LGPL-2.0-or-later
+
+    Copyright (C) KDE Developers
+
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
+*/
 
 #include "lastchangerecorder.h"
+#include "completionreplayer.h"
 #include <vimode/inputmodemanager.h>
 #include <vimode/keyparser.h>
-#include "completionreplayer.h"
 
 using namespace KateVi;
 
-bool KateVi::isRepeatOfLastShortcutOverrideAsKeyPress(const QKeyEvent& currentKeyPress, const QList<QKeyEvent>& keyEventLog)
+bool KateVi::isRepeatOfLastShortcutOverrideAsKeyPress(const QKeyEvent &currentKeyPress, const QList<QKeyEvent> &keyEventLog)
 {
     if (keyEventLog.empty())
         return false;
-    const QKeyEvent& lastKeyPress = keyEventLog.last();
-    if (lastKeyPress.type() == QEvent::ShortcutOverride && currentKeyPress.type() == QEvent::KeyPress &&
-        lastKeyPress.key() == currentKeyPress.key() &&
-        lastKeyPress.modifiers() == currentKeyPress.modifiers())
-    {
+    const QKeyEvent &lastKeyPress = keyEventLog.last();
+    if (lastKeyPress.type() == QEvent::ShortcutOverride && currentKeyPress.type() == QEvent::KeyPress && lastKeyPress.key() == currentKeyPress.key() && lastKeyPress.modifiers() == currentKeyPress.modifiers()) {
         return true;
     }
     return false;
@@ -86,15 +83,14 @@ QString LastChangeRecorder::encodedChanges() const
             key = text.at(0);
         }
 
-        if (text.isEmpty() || (text.length() == 1 && text.at(0) < 0x20)
-                || (mods != Qt::NoModifier && mods != Qt::ShiftModifier)) {
+        if (text.isEmpty() || (text.length() == 1 && text.at(0) < 0x20) || (mods != Qt::NoModifier && mods != Qt::ShiftModifier)) {
             QString keyPress;
 
             keyPress.append(QLatin1Char('<'));
-            keyPress.append((mods & Qt::ShiftModifier)   ? QStringLiteral("s-") : QString());
+            keyPress.append((mods & Qt::ShiftModifier) ? QStringLiteral("s-") : QString());
             keyPress.append((mods & Qt::ControlModifier) ? QStringLiteral("c-") : QString());
-            keyPress.append((mods & Qt::AltModifier)     ? QStringLiteral("a-") : QString());
-            keyPress.append((mods & Qt::MetaModifier)    ? QStringLiteral("m-") : QString());
+            keyPress.append((mods & Qt::AltModifier) ? QStringLiteral("a-") : QString());
+            keyPress.append((mods & Qt::MetaModifier) ? QStringLiteral("m-") : QString());
             keyPress.append(keyCode <= 0xFF ? QChar(keyCode) : KeyParser::self()->qt2vi(keyCode));
             keyPress.append(QLatin1Char('>'));
 
