@@ -1,36 +1,36 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2008 - 2009 Erlend Hamberg <ehamberg@gmail.com>
- *  Copyright (C) 2009 Paul Gideon Dann <pdgiddie@gmail.com>
- *  Copyright (C) 2011 Svyatoslav Kuzmich <svatoslav1@gmail.com>
- *  Copyright (C) 2012 - 2013 Simon St James <kdedevel@etotheipiplusone.com>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*  SPDX-License-Identifier: LGPL-2.0-or-later
+
+    Copyright (C) 2008 - 2009 Erlend Hamberg <ehamberg@gmail.com>
+    Copyright (C) 2009 Paul Gideon Dann <pdgiddie@gmail.com>
+    Copyright (C) 2011 Svyatoslav Kuzmich <svatoslav1@gmail.com>
+    Copyright (C) 2012 - 2013 Simon St James <kdedevel@etotheipiplusone.com>
+
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
+*/
 
 #ifndef KATEVI_NORMAL_VI_MODE_H
 #define KATEVI_NORMAL_VI_MODE_H
 
-#include <vimode/range.h>
 #include <vimode/modes/modebase.h>
+#include <vimode/range.h>
 
-#include <QVector>
-#include <QStack>
 #include <QHash>
 #include <QRegExp>
+#include <QStack>
+#include <QVector>
 
 #include <ktexteditor/range.h>
 #include <ktexteditor_export.h>
@@ -56,9 +56,9 @@ class KTEXTEDITOR_EXPORT NormalViMode : public ModeBase
 
 public:
     explicit NormalViMode(InputModeManager *viInputModeManager, KTextEditor::ViewPrivate *view, KateViewInternal *viewInternal);
-    virtual ~NormalViMode();
+    ~NormalViMode() override;
 
-    bool handleKeypress(const QKeyEvent *e) Q_DECL_OVERRIDE;
+    bool handleKeypress(const QKeyEvent *e) override;
 
     bool commandEnterInsertMode();
     bool commandEnterInsertModeAppend();
@@ -348,7 +348,7 @@ protected:
 
     unsigned int m_countTemp;
     int m_motionOperatorIndex;
-    uint m_scroll_count_limit;
+    int m_scroll_count_limit;
 
     QVector<Command *> m_commands;
     QVector<Motion *> m_motions;
